==> structToolbox_1.0.0.tar.gz: structToolbox/R/log_transform.R <==
#' log transform
#'
#' Applies a log transform to the input data
#' @param base The base of the logarithm. Default is 10, resulting in a log10 transformation of the data.
#' @param ... additional slots and values passed to struct_class
#' @return struct object
#' @export log_transform
#' @examples
#' M = log_transform()
log_transform = function(base=10,...) {
    out=struct::new_struct('log_transform',
        base=10,
        ...)
    return(out)
}


.log_transform<-setClass(
    "log_transform",
    contains = c('model'),
    slots=c(base='entity',
        transformed='entity'
    ),

    prototype=list(name = 'logarithm transform',
        description = 'applies a log tranform to the data.',
        type = 'transform',
        predicted = 'transformed',
        .params=c('base'),
        .outputs=c('transformed'),

        base=entity(name = 'logarithm base',
            description = 'The base of the logarithm used for the tranform.',
            value = 10,
            type='numeric'),

        transformed=entity(name = 'log transformed DatasetExperiment',
            description = 'A DatasetExperiment object containing the log transformed data.',
            type='DatasetExperiment',
            value=DatasetExperiment()
        )
    )
)

#' @export
#' @template model_apply
setMethod(f="model_apply",
    signature=c("log_transform","DatasetExperiment"),
    definition=function(M,D)
    {
        opt=param_list(M)

        smeta=D$sample_meta
        x=D$data

        out = log(x,base = opt$base)
        D$data = as.data.frame(out)

        output_value(M,'transformed') = D

        return(M)
    }
)

==> structToolbox_1.4.0.tar.gz: structToolbox/R/log_transform.R <==
#' @eval get_description('log_transform')
#' @return struct object
#' @export log_transform
#' @examples
#' M = log_transform()
log_transform = function(base=10,...) {
    out=struct::new_struct('log_transform',
        base=base,
        ...)
    return(out)
}


.log_transform<-setClass(
    "log_transform",
    contains = c('model','stato'),
    slots=c(base='entity',
        transformed='entity'
    ),

    prototype=list(name = 'logarithm transform',
        description = 'A logarithmic transform is applied to all values in the data matrix.',
        type = 'transform',
        predicted = 'transformed',
        .params=c('base'),
        .outputs=c('transformed'),
        stato_id = 'OBI:0200094',
        base=entity(name = 'Logarithm base',
            description = 'The base of the logarithm used for the transform.',
            value = 10,
            type='numeric'),

        transformed=entity(name = 'Log transformed DatasetExperiment',
            description = 'A DatasetExperiment object containing the log transformed data.',
            type='DatasetExperiment',
            value=DatasetExperiment()
        )
    )
)

#' @export
#' @template model_apply
setMethod(f="model_apply",
    signature=c("log_transform","DatasetExperiment"),
    definition=function(M,D)
    {
        opt=param_list(M)

        smeta=D$sample_meta
        x=D$data

        out = log(x,base = opt$base)
        D$data = as.data.frame(out)

        output_value(M,'transformed') = D

        return(M)
    }
)
